<?php
namespace Alpha\Sms\Helper;

use Magento\Framework\App\Helper\Context;
use Magento\Framework\App\Filesystem\DirectoryList;
use Monolog\Handler\StreamHandler;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Pricing\Helper\Data as PricingHelper;

class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
    public $logger;
    private $_resource;
    private $_pricingHelper;
    
    public function __construct(Context $cont, DirectoryList $dir_list, ResourceConnection $rsrc, PricingHelper $helper) {
        $this->_resource = $rsrc;
        $this->_pricingHelper = $helper;
        parent::__construct($cont);
    }

    public function getStoreConfig($path)
    {
        return $this->scopeConfig->getValue(
            $path,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }

    public function getVariables()
    {
        $variables = ['{ORDER-NUMBER}', '{ORDER-TOTAL}', '{ORDER-STATUS}', '{CARRIER-NAME}', '{PAYMENT-NAME}','{CUSTOMER-NAME}', '{CUSTOMER-EMAIL}'];
        return $variables;
    }

    public function getIsAlphaSent($order_id)
    {
        $connection= $this->_resource->getConnection();
        $table = $this->_resource->getTableName('sales_order');
        $query = "select is_alpha_send from {$table} where entity_id = ".(int)($order_id);
        return (int)($connection->fetchOne($query));
    }

    public function setIsAlphaSent($order_id)
    {
        $connection= $this->_resource->getConnection();
        $table = $this->_resource->getTableName('sales_order');
        $query = "update {$table} set is_alpha_send=1 where entity_id = ".(int)($order_id);
        $connection->query($query);
    }

    public function getIncrementId($order)
    {
        $incrementId = $order->getOriginalIncrementId();
        if ($incrementId == null || empty($incrementId) || !$incrementId) {
            $incrementId = $order->getIncrementId();
        }
        return $incrementId;
    }

    public function getNewOrderMessage($order)
    {
        
        $variables = $this->getVariables();
        $values = [
            $this->getIncrementId($order),
            strip_tags($this->_pricingHelper->currency($order->getGrandTotal())),
            $order->getStatus(),
            $order->getShippingDescription(),
            $order->getPayment()->getMethodInstance()->getTitle(),
            $order->getCustomerFirstname().' '.$order->getCustomerLastname(),
            $order->getCustomerEmail()
        ];
        $message = $this->getStoreConfig('alphasms/messages/sendsmsonnewordermessage');

        return  str_replace($variables, $values, $message);
    }

    public function getShippedStatusMessage($order)
    {
        $variables = $this->getVariables();
        $values = [
            $this->getIncrementId($order),
            strip_tags($this->_pricingHelper->currency($order->getGrandTotal())),
            $order->getStatus(),
            $order->getShippingDescription(),
            $order->getPayment()->getMethodInstance()->getTitle(),
            $order->getCustomerFirstname().' '.$order->getCustomerLastname(),
            $order->getCustomerEmail() ];
        $message = $this->getStoreConfig('alphasms/messages/sendsmsonshipmessage');

        return  str_replace($variables, $values, $message);
    }

    public function sendSMS($to, $body, $action, $id_order, $countryCode)
    {
        try {

            $from = $this->getStoreConfig('alphasms/settings/sender');
            $from = preg_replace('/\s+/', '', $from);
            $from = substr($from, 0, 11);

            $username = $this->getStoreConfig('alphasms/settings/username');
            $password = $this->getStoreConfig('alphasms/settings/password');

            $params = [
                'from'=>$from,
                'to'=>$to,
                'message'=>$body,
                'ask_date'=>date(DATE_ISO8601, time()),
                'wap'=>'',
                'flash'=>0,
                'class_version'=>'1.9',
                'login' => $username,
                'password' => $password,
                'command' => 'send',
            ];

            $params_url = '';
            foreach($params as $key=>$value)
                $params_url .= '&' . $key . '=' . $this->base64_url_encode($value);

            $ch = curl_init('https://alphasms.com.ua/api/http.php');
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 10);
            curl_setopt($ch, CURLOPT_POST, count($params));
            curl_setopt($ch, CURLOPT_POSTFIELDS, $params_url);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
            $response = @curl_exec($ch);

            if (!$response) {
                throw new \Magento\Framework\Exception\LocalizedException(curl_error($ch));
            }

            curl_close($ch);
        }
        catch (\Magento\Framework\Exception\LocalizedException $e) {
            throw new \Magento\Framework\Exception\LocalizedException($e->getMessage());
        }
    }
}
